@@ -57,7 +57,7 @@ try:
 except ImportError:
     pass
 
-__version__ = "3.5.0"
+__version__ = "3.7.0"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_BME680.git"
 
 
@@ -391,7 +391,7 @@ class Adafruit_BME680:
             var2 = self._adc_gas - 512
             var2 *= 3
             var2 = 4096 + var2
-            calc_gas_res = (1000 * var1) / var2
+            calc_gas_res = (10000 * var1) / var2
             calc_gas_res = calc_gas_res * 100
         else:
             var1 = (
@@ -482,30 +482,29 @@ class Adafruit_BME680:
     def _write(self, register: int, values: bytearray) -> None:
         raise NotImplementedError()
 
-    # garberw added begin ===========================
     def set_gas_heater(self, heater_temp: UINT16, heater_time: UINT16) -> bool:
         """
-        *  @brief  Enable and configure gas reading + heater
+        *  @brief  Enable and configure gas reading + heater (None disables)
         *  @param  heater_temp
         *          Desired temperature in degrees Centigrade
         *  @param  heater_time
         *          Time to keep heater on in milliseconds
         *  @return True on success, False on failure
         """
-        if (heater_temp == 0) or (heater_time == 0):
-            return False
-        # enable = BME68X_ENABLE
         try:
-            self._set_heatr_conf(heater_temp, heater_time)
+            if (heater_temp is None) or (heater_time is None):
+                self._set_heatr_conf(heater_temp or 0, heater_time or 0, enable=False)
+            else:
+                self._set_heatr_conf(heater_temp, heater_time)
         except GasHeaterException:
             return False
         return True
 
-    def _set_heatr_conf(self, heater_temp: UINT16, heater_time: UINT16) -> None:
+    def _set_heatr_conf(
+        self, heater_temp: UINT16, heater_time: UINT16, enable: bool = True
+    ) -> None:
         # restrict to BME68X_FORCED_MODE
         op_mode: UINT8 = _BME68X_FORCED_MODE
-        # restrict to enable = True
-        enable: bool = True
         nb_conv: UINT8 = 0
         hctrl: UINT8 = _BME68X_ENABLE_HEATER
         run_gas: UINT8 = 0
